@@ -17,7 +17,6 @@ def get_widget(field, disabled=False):
     if disabled or \
             isinstance(field, ObjectIdField) or \
             isinstance(field, ListField) or \
-            isinstance(field, ReferenceField) or \
             isinstance(field, EmbeddedDocumentField):
         attrs['class'] += ' disabled'
         attrs['readonly'] = 'readonly'
@@ -30,5 +29,8 @@ def get_widget(field, disabled=False):
         
     if isinstance(field, BooleanField):
         return forms.CheckboxInput(attrs=attrs)
+        
+    if isinstance(field, ReferenceField):
+        return forms.Select(attrs=attrs)
 
     return forms.TextInput(attrs=attrs)
\ No newline at end of file
